@@ -1,10 +1,11 @@
 import pandas as pd
 import numpy as np
-from DirectoryFormulas import DirX
 
 TradeLIST = []
 AnalysisLIST = []
 
+from DirectoryFormulas import Directories
+
 def Statistics_OPT(opt_runs, margin, Mininbars = 0):
     st0 = [s[0] for s in opt_runs]
     for s in st0:
